==> basicshib-3.0.0.tar.gz: basicshib/src/Form/GrouperSettingsForm.php <==
<?php

namespace Drupal\basicshib\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Config\ConfigFactoryInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\basicshib\GrouperHelperTrait;

/**
 * Class CoreSettingsForm.
 */
class GrouperSettingsForm extends ConfigFormBase
{
  use GrouperHelperTrait;

  /**
   * The User's Drupal roles.
   *
   * @var array
   */
  protected array $roles;

  /**
   * Constructs a new GrouperSettingsForm object.
   *
   * @param ConfigFactoryInterface $config_factory
   */
  public function __construct(ConfigFactoryInterface $config_factory)
  {
    parent::__construct($config_factory);
    $this->roles = $this->getDrupalRoles();
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container): GrouperSettingsForm {
    return new static(
      $container->get('config.factory')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'grouper_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames(): array {
    return [
      'basicshib.grouper_settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    $form['grouper_enabled'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enable Grouper'),
      '#default_value' => $this->config('basicshib.grouper_settings')
        ->get('grouper_enabled'),
      '#attributes' => [
        'name' => 'grouper_enabled',
      ],
    ];

    $form['roles'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Roles'),
      '#states' => [
        'visible' => [
          ':input[name="grouper_enabled"]' => ['checked' => TRUE],
        ],
      ],
    ];

    foreach ($this->roles as $index => $value) {
      $form['roles']['list' . $index] = [
        '#type' => 'textfield',
        '#title' => $this->t($value),
        '#description' => $this->t('groups assigned to this role'),
        '#default_value' => $this->config('basicshib.grouper_settings')
          ->get('role_' . $index),
      ];
    }

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state)
  {
    parent::validateForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state)
  {
    parent::submitForm($form, $form_state);

    foreach ($this->roles as $index => $value) {
      $this->config('basicshib.grouper_settings')
        ->set('role_' . $index, $form_state->getValue('list' . $index));
    }
    $this->config('basicshib.grouper_settings')
      ->set('grouper_enabled', $form_state->getValue('grouper_enabled'))
      ->save();
  }
}

==> basicshib-3.0.3.tar.gz: basicshib/src/Form/GrouperSettingsForm.php <==
<?php

namespace Drupal\basicshib\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Config\ConfigFactoryInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\basicshib\GrouperHelperTrait;

/**
 * Class CoreSettingsForm.
 */
class GrouperSettingsForm extends ConfigFormBase {
  use GrouperHelperTrait;

  /**
   * The User's Drupal roles.
   *
   * @var array
   */
  protected array $roles;

  /**
   * Constructs a new GrouperSettingsForm object.
   */
  public function __construct(ConfigFactoryInterface $config_factory) {
    parent::__construct($config_factory);
    $this->roles = $this->getDrupalRoles();
  }

  /**
   * @param \Symfony\Component\DependencyInjection\ContainerInterface $container
   *
   * @return \Drupal\basicshib\Form\GrouperSettingsForm
   */
  public static function create(ContainerInterface $container): GrouperSettingsForm {
    return new static(
      $container->get('config.factory')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'grouper_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames(): array {
    return [
      'basicshib.grouper_settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    $form['grouper_enabled'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enable Grouper'),
      '#default_value' => $this->config('basicshib.grouper_settings')
        ->get('grouper_enabled'),
      '#attributes' => [
        'name' => 'grouper_enabled',
      ],
    ];

    $form['roles'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Roles'),
      '#states' => [
        'visible' => [
          ':input[name="grouper_enabled"]' => ['checked' => TRUE],
        ],
      ],
    ];

    foreach ($this->roles as $index => $value) {
      $form['roles']['list' . $index] = [
        '#type' => 'textfield',
        '#title' => $this->t($value),
        '#description' => $this->t('groups assigned to this role'),
        '#default_value' => $this->config('basicshib.grouper_settings')
          ->get('role_' . $index),
      ];
    }

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    parent::validateForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);

    foreach ($this->roles as $index => $value) {
      $this->config('basicshib.grouper_settings')
        ->set('role_' . $index, $form_state->getValue('list' . $index));
    }
    $this->config('basicshib.grouper_settings')
      ->set('grouper_enabled', $form_state->getValue('grouper_enabled'))
      ->save();
  }

}
